pub enum LastFMErrorResponse {
Show 14 variants
InvalidService(LastFMError),
InvalidMethod(LastFMError),
AuthenticationFailed(LastFMError),
InvalidFormat(LastFMError),
InvalidParameters(LastFMError),
InvalidResourceSpecified(LastFMError),
OperationFailed(LastFMError),
InvalidSessionKey(LastFMError),
InvalidAPIKey(LastFMError),
ServiceOffline(LastFMError),
InvalidMethodSignatureSupplied(LastFMError),
GenericError(LastFMError),
SuspendedAPIKey(LastFMError),
RateLimitExceeded(LastFMError),
}Expand description
Representation of all the errors exposed by the Last.fm API.
Variants
InvalidService(LastFMError)
Invalid Service - This service does not exist.
InvalidMethod(LastFMError)
Invalid Method - No method exists by the name provided.
AuthenticationFailed(LastFMError)
Authentication Failed - Failed to authenticate with the Last.fm API.
InvalidFormat(LastFMError)
Invalid Format - Service does not exist in the format given.
InvalidParameters(LastFMError)
Invalid Parameters - A required parameter is missing from the request, or one or more parameters are invalid.
InvalidResourceSpecified(LastFMError)
Invalid Resource Specified - An invalid resource was specified.
OperationFailed(LastFMError)
Operation Failed - Something else went wrong.
InvalidSessionKey(LastFMError)
Invalid Session Key - Please re-authenticate with the Last.fm API.
InvalidAPIKey(LastFMError)
Invalid API Key - An invalid API key was provided.
ServiceOffline(LastFMError)
Service Offline - The given service is temporarily offline. Try again later.
InvalidMethodSignatureSupplied(LastFMError)
Invalid Method Signature Supplied - An invalid signature for the given methoid was supplied.
GenericError(LastFMError)
Generic Error - An unknown error has occurred.
SuspendedAPIKey(LastFMError)
Suspended API Key - The given API key has been suspended.
RateLimitExceeded(LastFMError)
Rate Limit Exceeded - The rate limit for this API key has been exceeded.